@@ -4,6 +4,9 @@ def make_setup(project, author, email, git_account):
 from setuptools import setup, find_packages
 from {project} import __VERSION__
 
+def _requires_from_file(filename):
+    return open(filename).read().splitlines()
+
 with open('README.md') as f:
     readme = f.read()
 
@@ -24,7 +27,8 @@ setup(
     author_email='{email}',
     url='https://github.com/{git_account}/{project}',
     license=license_txt,
-    packages=find_packages(exclude=('sample',))
+    packages=find_packages(exclude=('sample',)),
+    install_requires=_requires_from_file('requirements.txt')
 )"""
     with open('setup.py', 'w') as f:
         f.write(template)
